﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;


using System.Windows.Controls;
using System.Windows.Media;
using System.Windows;
using System.Globalization;


namespace Schacht {
    public class WinkelGraphic : Control {

        private FormattedText formattedText;
        private double linkerRand = 0.0;
        private double fontHeight = 0.0;
        private Color brushText = Colors.Black;
        private Color brushRand = Colors.Aqua;

        private Pen penBlack = new Pen(Brushes.Black, 1);
        private Pen penRand = new Pen(Brushes.Black, 5);
        private Pen penZuAblauf = new Pen(Brushes.Red, 10);

        private double winkel = 0.0;
        private bool isWinkel = false;
        public double Winkel {
            set {
                winkel = value;
                isWinkel = true;
                this.InvalidateVisual();
            }
            get { return winkel; }
        }

        public WinkelGraphic() {
            formattedText = new FormattedText("8888.88", CultureInfo.GetCultureInfo("DE-de"), FlowDirection.LeftToRight,
                new Typeface("Verdana"), 11, new SolidColorBrush(brushText)); // text.brushText));   
            linkerRand = formattedText.Width;
            fontHeight = formattedText.Height;
        }

        protected override void OnRender(DrawingContext dc) {
            base.OnRender(dc);
            double width = this.ActualWidth;
            double height = this.ActualHeight;
            double w = width - fontHeight - fontHeight;
            double h = height - fontHeight - fontHeight;
            Rect rect = new Rect(0, 0, Width, Height);
            dc.DrawRectangle(Brushes.White, penBlack, rect);
            dc.DrawEllipse(new SolidColorBrush(brushRand), penRand, new Point(width * 0.5, height * 0.5), w * 0.5, h * 0.5);
            if (isWinkel) {
                double xp, yp, r;
                if (width > height)
                    r = height * 0.5;
                else
                    r = width * 0.5;
                calcXpYp(winkel, r, out xp, out yp);
                Point p1, p2;
                double x0, y0;
                x0 = width * 0.5;
                y0 = height * 0.5;
                p1 = new Point(x0, y0);
                p2 = new Point(x0 + xp, y0 - yp);
                // winkel = value;
                dc.DrawLine(penZuAblauf, p1, p2);
            }


        } // protected override void OnRender(DrawingContext dc) {

        private void calcXpYp(double winkel, double r, out double xp, out double yp) {
            double alpha = winkel;
            if (alpha > 100.0 && alpha <= 200.0) {
                alpha = 100.0 - (alpha - 100.0);
            }
            else if (alpha > 200.0 && alpha <= 300.0) {
                alpha -= 200.0;
            }
            else if (alpha > 300.0 && alpha <= 400.0) {
                alpha = 100.0 - (alpha - 300.0);
            }
            // nun Image Bereich 0 bis 100.0
            double beta = 100.0 - alpha;
            double y = r * Math.Sin(beta * Math.PI * 0.005);
            double x = r * Math.Cos(beta * Math.PI * 0.005);
            if (winkel >= 0.0 && winkel <= 100.0) {
                xp = x;
                yp = y;
            }
            else if (winkel > 100.0 && winkel <= 200.0) {
                xp = x;
                yp = -y;
            }
            else if (winkel > 200.0 && winkel <= 300.0) {
                xp = -x;
                yp = -y;
            }
            else {
                xp = -x;
                yp = y;
            }
        }

    }
}
